#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
:copyright:
    Yangkang Chen (chenyk2016@gmail.com), 2022-Present 
:license:
    GNU General Public License, Version 3
    (http://www.gnu.org/copyleft/gpl.html)
"""

__version__ = "0.0.0"

from .fmm import eikonal


# This is my first C-extension (more will be coming), the first step to make the codes faster
from calculator import *















def eikonal(xyz,ax=[0,0.01,101],ay=[0,0.01,101],az=[0,0.01,101],order=2):
	'''
	eikonal: Fast marching eikonal solver (3-D)
	
	INPUT
	xyz:
	ax: axis x
	ay: axis y
	az: axis z
	
	OUTPUT
	times: traveltime (numpy array)
	
	EXAMPLE
	
	'''
	
	times=[]

	return times